ScopeArea class

Constructors

ScopeArea(Node node, {required Scope scope, ScopeArea? parent})

Properties

children → List<ScopeArea>
final
hashCode → int
The hash code for this object.
no setterinherited
node ↔ Node
getter/setter pair
parent ↔ ScopeArea?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ Scope
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited